@@ -779,162 +779,3 @@ gpk_package_entry_completion_new (void)
 
 	return completion;
 }
-
-/***************************************************************************
- ***                          MAKE CHECK TESTS                           ***
- ***************************************************************************/
-#ifdef EGG_TEST
-#include "egg-test.h"
-
-void
-gpk_common_test (gpointer data)
-{
-	gchar *text;
-	EggTest *test = (EggTest *) data;
-
-	if (!egg_test_start (test, "GpkCommon"))
-		return;
-
-	/************************************************************
-	 ****************        time text             **************
-	 ************************************************************/
-	egg_test_title (test, "time zero");
-	text = gpk_time_to_localised_string (0);
-	if (text != NULL && strcmp (text, "Now") == 0)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "failed, got %s", text);
-	g_free (text);
-
-	/************************************************************/
-	egg_test_title (test, "time 1s");
-	text = gpk_time_to_localised_string (1);
-	if (text != NULL && strcmp (text, "1 second") == 0)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "failed, got %s", text);
-	g_free (text);
-
-	/************************************************************/
-	egg_test_title (test, "time 1m");
-	text = gpk_time_to_localised_string (1*60);
-	if (text != NULL && strcmp (text, "1 minute") == 0)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "failed, got %s", text);
-	g_free (text);
-
-	/************************************************************/
-	egg_test_title (test, "time 1h");
-	text = gpk_time_to_localised_string (1*60*60);
-	if (text != NULL && strcmp (text, "1 hour") == 0)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "failed, got %s", text);
-	g_free (text);
-
-	/************************************************************/
-	egg_test_title (test, "time 30s");
-	text = gpk_time_to_localised_string (30);
-	if (text != NULL && strcmp (text, "30 seconds") == 0)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "failed, got %s", text);
-	g_free (text);
-
-	/************************************************************/
-	egg_test_title (test, "time 30m");
-	text = gpk_time_to_localised_string (30*60);
-	if (text != NULL && strcmp (text, "30 minutes") == 0)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "failed, got %s", text);
-	g_free (text);
-
-	/************************************************************/
-	egg_test_title (test, "time 30m1s");
-	text = gpk_time_to_localised_string (30*60+1);
-	if (text != NULL && strcmp (text, "30 minutes 1 second") == 0)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "failed, got %s", text);
-	g_free (text);
-
-	/************************************************************/
-	egg_test_title (test, "time 30m10s");
-	text = gpk_time_to_localised_string (30*60+10);
-	if (text != NULL && strcmp (text, "30 minutes 10 seconds") == 0)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "failed, got %s", text);
-	g_free (text);
-
-	/************************************************************/
-	egg_test_title (test, "imprecise time 1s");
-	text = gpk_time_to_imprecise_string (1);
-	if (text != NULL && strcmp (text, "1 second") == 0)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "failed, got %s", text);
-	g_free (text);
-
-	/************************************************************/
-	egg_test_title (test, "imprecise time 30m");
-	text = gpk_time_to_imprecise_string (30*60);
-	if (text != NULL && strcmp (text, "30 minutes") == 0)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "failed, got %s", text);
-	g_free (text);
-
-	/************************************************************/
-	egg_test_title (test, "imprecise time 30m10s");
-	text = gpk_time_to_imprecise_string (30*60+10);
-	if (text != NULL && strcmp (text, "30 minutes") == 0)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "failed, got %s", text);
-	g_free (text);
-
-	/************************************************************
-	 ****************     package name text        **************
-	 ************************************************************/
-	egg_test_title (test, "package id pretty valid package id, no summary");
-	text = gpk_package_id_format_twoline (NULL, "simon;0.0.1;i386;data", NULL);
-	if (text != NULL && strcmp (text, "simon-0.0.1 (32-bit)") == 0)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "failed, got %s", text);
-	g_free (text);
-
-	/************************************************************/
-	egg_test_title (test, "package id pretty valid package id, no summary 2");
-	text = gpk_package_id_format_twoline (NULL, "simon;0.0.1;;data", NULL);
-	if (text != NULL && strcmp (text, "simon-0.0.1") == 0)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "failed, got %s", text);
-	g_free (text);
-
-	/************************************************************/
-	egg_test_title (test, "package id pretty valid package id, no summary 3");
-	text = gpk_package_id_format_twoline (NULL, "simon;;;data", NULL);
-	if (text != NULL && strcmp (text, "simon") == 0)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "failed, got %s", text);
-	g_free (text);
-
-	/************************************************************/
-	egg_test_title (test, "package id pretty valid package id, no summary 4");
-	text = gpk_package_id_format_twoline (NULL, "simon;0.0.1;;data", "dude");
-	if (text != NULL && strcmp (text, "dude\n<span color=\"gray\">simon-0.0.1</span>") == 0)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, "failed, got %s", text);
-	g_free (text);
-
-	egg_test_end (test);
-}
-#endif
-
