@@ -756,8 +756,7 @@ gpk_error_enum_to_localised_message (PkErrorEnum code)
 		text = _("A package manager lock is required.");
 		break;
 	default:
-		g_warning ("Unknown error, please report a bug at " GPK_BUGZILLA_URL ".\n"
-			    "More information is available in the detailed report.");
+		break;
 	}
 	return text;
 }
